@@ -40,7 +40,7 @@ static void usage();
 static void PrintValues();
 static int maxncond = 100;
 
-static char *RevMsg = "GETFTAB WCSTools 3.9.5, 30 March 2017, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETFTAB WCSTools 3.9.6, 14 May 2020, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int nfile = 0;
