@@ -1,9 +1,9 @@
 /* File getpix.c
- * June 9, 2016
+ * May 14, 2020
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics)
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1996-2016
+   Copyright (C) 1996-2020
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -41,12 +41,12 @@ static void usage();
 static void PrintPix();
 static void procpix();
 
-static char *RevMsg = "GETPIX WCSTools 3.9.5, 30 March 2017, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETPIX WCSTools 3.9.6, 14 May 2020, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose/debugging flag */
 static int version = 0;		/* If 1, print only program name and version */
-static int nline = 10;		/* Number of pixels printer per line */
-static char *pform = NULL;	/* Format in which to print pixels */
+static int nline = 10;		/* Number of pixels displayed per line */
+static int ndec = -1;		/* Format in which to print pixels */
 static int pixlabel = 0;	/* If 1, label pixels in output */
 static int gtcheck = 0;		/* If 1, list pixels greater than gtval */
 static int ltcheck = 0;		/* If 1, list pixels less than ltval */
@@ -54,6 +54,7 @@ static int nopunct=0;		/* If 1, print output with no punctuation */
 static int printrange = 0;	/* If 1, print range of values, not values */
 static int printmean = 0;	/* If 1, print mean of values, not values */
 static int printname = 0;	/* If 1, print file name */
+static int bycol = 0;		/* If 1, display column as line */
 static double gtval = 0.0;
 static double ltval = 0.0;
 static double ra0 = -99.0;	/* Initial center RA in degrees */
@@ -66,6 +67,7 @@ static int syscoor = 0;         /* Input search coordinate system */
 static int identifier = 0;	/* If 1, identifier precedes x y in file */
 static int printtab = 0;	/* If 1, separate number with tabs */
 static int procinit = 1;	/* If 1, start mean and limits */
+static char pformat[8];		/* If not null, format for pixels without leading % */
 
 int
 main (ac, av)
@@ -79,8 +81,8 @@ char **av;
     char filename[256];
     int ifile, nbytes;
     FILE *flist;
-    char *rrange;       /* Row range string */
-    char *crange;       /* Column range string */
+    char *xrange;       /* Horizontal(x) range string */
+    char *yrange;       /* Vertical(y) range string */
     char *rstr;
     char *dstr = NULL;
     char *cstr;
@@ -88,6 +90,8 @@ char **av;
     int i;
     int npix = 0;
     int nfile;
+    int ixnum, iynum;
+    int ixrange, iyrange;
     char linebuff[1024];
     char listname[256];
     char *line;
@@ -103,6 +107,7 @@ char **av;
     fn = (char **)calloc (maxnfile, sizeof(char *));
     xpix = (int *)calloc (maxnpix, sizeof (int));
     ypix = (int *)calloc (maxnpix, sizeof (int));
+    pformat[0] = (char) 0;
 
     /* Check for help or version command first */
     str = *(av+1);
@@ -113,24 +118,27 @@ char **av;
 	usage();
 	}
 
-    crange = NULL;
-    rrange = NULL;
+    xrange = NULL;
+    yrange = NULL;
 
     /* crack arguments */
     for (av++; --ac > 0; av++) {
 	str = *av;
-	if (ac > 0)
+	ixnum = isnum (str);
+	ixrange = isrange (str);
+	if (ac > 0) {
 	    str1 = *(av+1);
-	else
+	    iynum = isnum (str1);
+	    iyrange = isrange (str1);
+	    }
+	else {
 	    str1 = NULL;
-
-	/* Output format */
-	if (str[0] == '%') {
-	    pform = *av;
+	    iynum = 0;
+	    iyrange = 0;
 	    }
 
-	/* Other command */
-	else if (str[0] == '-') {
+	/* Command */
+	if (str[0] == '-') {
 	    char c;
 	    while ((c = *++str))
 	    switch (c) {
@@ -139,7 +147,14 @@ char **av;
 		    verbose++;
 		    break;
 
-		case 'd':	/* Print range of values */
+		case 'd':	/* Display this number of decimal places */
+		    if (ac < 2)
+			usage();
+		    ndec = atoi (*++av);
+		    ac--;
+		    break;
+
+		case 'e':	/* Print range of values */
 		    printrange=1;
 		    break;
 
@@ -178,6 +193,13 @@ char **av;
 		    ac--;
 		    break;
 
+		case 'o':	/* Output pixel format without leading % */
+		    if (ac < 2)
+			usage();
+		    strncpy (pformat, *++av, 8);
+		    ac--;
+		    break;
+
 		case 'p':	/* label pixels */
 		    pixlabel++;
 		    break;
@@ -216,6 +238,10 @@ char **av;
 		    printtab++;
 		    break;
 
+		case 'y':	/* Display by column instead of line */
+		    bycol++;
+		    break;
+
 		default:
 		    usage();
 		    break;
@@ -223,9 +249,10 @@ char **av;
 	    }
 
 	/* Set search RA, Dec, and equinox if colon in argument */
-	else if (isnum (str) == 3 && isnum (str1) == 3) {
-	    if (ac < 2)
+	else if (ixnum == 3 && iynum == 3) {
+	    if (ac < 2) {
 		usage ();
+		}
 	    else {
 		strcpy (rstr, str);
 		ac--;
@@ -248,7 +275,7 @@ char **av;
 	    }
 
 	/* Search coordinates in degrees if coordinate system specified */
-	else if (isnum (str) == 2 && isnum (str) == 2) {
+	else if (ixnum == 2 && iynum == 2) {
 	    rstr = str;
 	    dstr = str1;
 	    ac--;
@@ -297,8 +324,24 @@ char **av;
 		}
 	    }
 
+	/* Ranges of x and y pixels to print (only one pair allowed) */
+        else if (ixrange && iynum || ixnum && iyrange || ixrange && iyrange) {
+	    xrange = str;
+	    yrange = str1;
+	    ac--;
+	    av++;
+	    }
+
+	/* Two zeroes indicates that the entire image should be printed */
+        else if (!strcmp (str, "0") && !strcmp (str, "0")) {
+	    xrange = str;
+	    yrange = str1;
+	    ac--;
+	    av++;
+	    }
+
 	/* Coordinate pairs for pixels to print */
-        else if (isnum (str) == 1 && isnum (str1) == 1) {
+        else if (ixnum == 1 && iynum == 1) {
 	    if (npix+1 > maxnpix) {
 		maxnpix = 2 * maxnpix;
 		xp1 = calloc (maxnpix, sizeof (int));
@@ -315,8 +358,8 @@ char **av;
 	    ix = atoi (str);
 	    iy = atoi (str1);
 	    if (ix == 0 || iy == 0) {
-		crange = str1;
-		rrange = str;
+		xrange = str1;
+		yrange = str;
 		}
 	    else {
 	        xpix[npix] = ix;
@@ -327,14 +370,6 @@ char **av;
 	    ac--;
 	    }
 
-	/* Range of pixels to print (only one allowed) */
-        else if (isrange (str) && isrange (str1)) {
-	    rrange = str;
-	    crange = str1;
-	    ac--;
-	    av++;
-	    }
-
 	/* File containing a list of files or image coordinates */
 	else if (str[0] == '@') {
 	    strcpy (listname, str+1);
@@ -392,12 +427,12 @@ char **av;
 	    }
 	}
 
-    if ((crange && rrange) || npix > 0) {
+    if ((xrange && yrange) || npix > 0) {
 
 	/* Process files already read from the command line */
-	if (fn) {
+	if (nfile) {
 	    for (ifile = 0; ifile < nfile; ifile++) {
-		PrintPix (fn[ifile], crange, rrange, npix, xpix, ypix);
+		PrintPix (fn[ifile], xrange, yrange, npix, xpix, ypix);
 		}
 	    }
 
@@ -411,7 +446,7 @@ char **av;
 		}
 	    for (ifile = 0; ifile < nfile; ifile++) {
 		first_token (flist, 254, filename);
-		PrintPix (filename, crange, rrange, npix, xpix, ypix);
+		PrintPix (filename, xrange, yrange, npix, xpix, ypix);
 		}
 	    fclose (flist);
 	    }
@@ -430,12 +465,12 @@ usage ()
     if (version)
 	exit (-1);
     fprintf (stderr,"Print FITS or IRAF pixel values\n");
-    fprintf(stderr,"Usage: getpix [-vp][-n num][-g val][-l val][format] file.fit x_range y_range\n");
-    fprintf(stderr,"  or   getpix [-vp][-n num][-g val][-l val][format] file.fit x1 y1 x2 y2 ... xn yn\n");
-    fprintf(stderr,"  or   getpix [-vp][-n num][-g val][-l val][format] file.fit @file\n");
-    fprintf(stderr,"  format: C-style (%%f, %%d, ...) format for pixel values\n");
+    fprintf(stderr,"Usage: getpix [-vp][-n num][-g val][-l val] file.fits x_range y_range\n");
+    fprintf(stderr,"  or   getpix [-vp][-n num][-g val][-l val] file.fits x1 y1 x2 y2 ... xn yn\n");
+    fprintf(stderr,"  or   getpix [-vp][-n num][-g val][-l val] file.fits @file\n");
     fprintf(stderr,"  file: File with x y coordinates as first two tokens on lines\n");
-    fprintf(stderr,"  -d: Print range of pixel values in specified image region\n");
+    fprintf(stderr,"  -d: Number of decimal places in displayed pixel values\n");
+    fprintf(stderr,"  -e: Print range of pixel values in specified image region\n");
     fprintf(stderr,"  -f name: Write specified region to a FITS file\n");
     fprintf(stderr,"  -g num: keep pixels with values greater than this\n");
     fprintf(stderr,"  -h: print file name on line above pixel values\n");
@@ -443,26 +478,30 @@ usage ()
     fprintf(stderr,"  -l num: keep pixels with values less than this\n");
     fprintf(stderr,"  -m: Print mean of pixel values in specified image region\n");
     fprintf(stderr,"  -n num: number of pixel values printed per line\n");
+    fprintf(stderr,"  -o format: Output format in C style without leading %%\n");
     fprintf(stderr,"  -p: label pixels\n");
     fprintf(stderr,"  -r num: radius (<0=box) to extract in degrees/arcsec\n");
     fprintf(stderr,"  -s: print x y value with no punctuation\n");
+    fprintf(stderr,"  -t: separate columns in table with tabs not spaces \n");
     fprintf(stderr,"  -v: verbose\n");
-    fprintf(stderr,"   %%: C format for each pixel value\n");
+    fprintf(stderr,"  -y: display by column instead of by row\n");
     exit (1);
 }
 
 
 static void
-PrintPix (name, crange, rrange, npix, xpix, ypix)
+PrintPix (name, xrange, yrange, npix, xpix, ypix)
 
 char *name;
-char *crange;		/* Column range string */
-char *rrange;		/* Row range string */
+char *xrange;		/* Horizontal(x) range string */
+char *yrange;		/* Vertical(y) range string */
 int npix;		/* Number of coordinate pairs */
 int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 
 {
     char *header;	/* FITS image header */
+    char pform[8];	/* Pixel display format */
+    char testval[32];	/* Test value string for column header formatting */
     int lhead;		/* Maximum number of bytes in FITS header */
     int nbhead;		/* Actual number of bytes in FITS header */
     char *irafheader;	/* IRAF image header */
@@ -470,15 +509,17 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
     double bzero;	/* Zero point for pixel scaling */
     double bscale;	/* Scale factor for pixel scaling */
     int iraffile;
+    int lf;
+    int intout = 0;	/* Display output pixel values as integer if =1 */
     double dpix, dsum, dmean, dmin, dmax, dnpix;
     char *c;
-    int *yi;
-    int bitpix,xdim,ydim, i, nx, ny, ix, iy, x, y, pixperline;
+    int *yi, *xi;
+    int bitpix, xdim, ydim, i, nx, ny, ix, iy, x, y, x1, y1, pixperline, ndig;
     int ipix = 0;
     char pixname[255];
-    char nform[8];
-    struct Range *xrange;    /* X range structure */
-    struct Range *yrange;    /* Y range structure */
+    char cform[8], rform[8];
+    struct Range *crange;    /* Column (nominally x) range structure */
+    struct Range *rrange;    /* Row (nominally y) range structure */
 
     /* Open IRAF image if .imh extension is present */
     if (isiraf (name)) {
@@ -529,16 +570,35 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 	else
 	    fprintf (stderr,"%s:\n", name);
 	}
+
+    /* Get size of image and scaling factors */
+    bitpix = 32;
+    hgeti4 (header,"BITPIX",&bitpix);
+    xdim = 1;
+    hgeti4 (header,"NAXIS1",&xdim);
+    ydim = 1;
+    hgeti4 (header,"NAXIS2",&ydim);
+    bzero = 0.0;
+    hgetr8 (header,"BZERO",&bzero);
+    bscale = 1.0;
+    hgetr8 (header,"BSCALE",&bscale);
+
     if (verbose) {
 	fprintf (stderr,"%s\n",RevMsg);
 	if (npix > 0)
-	    fprintf (stderr,"Print pixels in ");
-	else if (!strcmp (crange, "0"))
-	    fprintf (stderr,"Print rows %s in ", rrange);
-	else if (!strcmp (rrange, "0"))
-	    fprintf (stderr,"Print columns %s in ", crange);
+	    fprintf (stderr,"Print pixels of ");
+	else if (!strcmp (xrange, "0") && !strcmp (yrange, "0"))
+	    fprintf (stderr,"Print x  1-%d columns, y 1-%d rows of ", xdim, ydim);
+	else if (!strcmp (xrange, "0"))
+	    fprintf (stderr,"Print x 1-%d columns, y %s rows of ", xdim, yrange);
+	else if (bycol && !strcmp (yrange, "0"))
+	    fprintf (stderr,"Print y 1-%d columns, x %s rows of ", ydim, xrange);
+	else if (!strcmp (yrange, "0"))
+	    fprintf (stderr,"Print x %s columns, y 1-%d rows of ", xrange, ydim);
+	else if (bycol)
+	    fprintf (stderr,"Print y %s columns , x %s rows of ", yrange, xrange);
 	else
-	    fprintf (stderr,"Print rows %s, columns %s in ", rrange, crange);
+	    fprintf (stderr,"Print x %s rows, y %s columns of ", xrange, yrange);
 	if (iraffile)
 	    fprintf (stderr,"IRAF image file %s\n", name);
 	else
@@ -555,18 +615,7 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
     else
 	pixperline = 0;
 
-/* Get value of specified pixel */
-
-    /* Get size of image and scaling factors */
-    hgeti4 (header,"BITPIX",&bitpix);
-    xdim = 1;
-    hgeti4 (header,"NAXIS1",&xdim);
-    ydim = 1;
-    hgeti4 (header,"NAXIS2",&ydim);
-    bzero = 0.0;
-    hgetr8 (header,"BZERO",&bzero);
-    bscale = 1.0;
-    hgetr8 (header,"BSCALE",&bscale);
+/* Set up pixel access and display */
 
     /* Set initial values */
     dsum = 0.0;
@@ -576,12 +625,29 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
     procinit = 1;
 
     /* Set format if not already set */
-    if (pform == NULL) {
-	pform = (char *) calloc (8,1);
-	if (bitpix > 0)
-	    strcpy (pform, "%d");
-	else
-	    strcpy (pform, "%.2f");
+    for (i = 0; i < 8; i++)
+	pform[i] = (char) 0;
+    if (pformat[0] != (char) 0) {
+	sprintf (pform, "%%%s", pformat);
+	lf = strlen (pformat);
+	if (pformat[lf-1] == 'd')
+	    intout = 1;
+	}
+    else if (ndec == 0) {
+	sprintf (pform, "%%d");
+	intout = 1;
+	}
+    else if (ndec > 0)  {
+	sprintf (pform, "%%.%df", ndec);
+	intout = 0;
+	}
+    else if (bitpix > 0) {
+	strcpy (pform, "%%d");
+	intout = 1;
+	}
+    else {
+	strcpy (pform, "%%.2f");
+	intout = 0;
 	}
 
 /* Print values at specified coordinates in an image  */
@@ -594,20 +660,32 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 		if ((gtcheck && dpix > gtval) ||
 		    (ltcheck && dpix < ltval)) {
 		    procpix (&dsum, &dnpix, &dmin, &dmax, dpix);
+		    if (intout) {
+			if (dpix > 0)
+		 	    ipix = (int) (dpix + 0.5);
+			else if (dpix < 0)
+			     ipix = (int) (dpix - 0.5);
+			else
+			    ipix = 0;
+			}
 		    if (nopunct)
-			printf ("%d %d %f\n", xpix[i], ypix[i], dpix);
+			printf ("%d %d \n", xpix[i], ypix[i]);
 		    else
-			printf ("[%d,%d] = %f\n", xpix[i], ypix[i], dpix);
+			printf ("[%d,%d] = \n", xpix[i], ypix[i]);
+		    if (intout)
+			printf (pform, ipix);
+		    else
+			printf (pform, dpix);
+		    printf ("\n");
 		    }
 		continue;
 		}
+
 	    else
 		procpix (&dsum, &dnpix, &dmin, &dmax, dpix);
 	    if (printrange || printmean)
 		continue;
-	    if (bitpix > 0) {
-		if ((c = strchr (pform,'f')) != NULL)
-		    *c = 'd';
+	    if (intout) {
 		if (dpix > 0)
 	 	    ipix = (int) (dpix + 0.5);
 		else if (dpix < 0)
@@ -615,20 +693,16 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 		else
 		    ipix = 0;
 		}
-	    else {
-		if ((c = strchr (pform,'d')) != NULL)
-		    *c = 'f';
-		}
 	    if (pixperline) {
 		printf ("%s[%d,%d] = ",name,xpix[i],ypix[i]);
-		if (bitpix > 0)
+		if (intout)
 		    printf (pform, ipix);
 		else
 		    printf (pform, dpix);
 		printf ("\n");
 		}
 	    else {
-		if (bitpix > 0)
+		if (intout)
 		    printf (pform, ipix);
 		else
 		    printf (pform, dpix);
@@ -645,7 +719,7 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 	}
 
 /* Print entire image */
-    else if (!strcmp (rrange, "0") && !strcmp (crange, "0")) {
+    else if (!strcmp (xrange, "0") && !strcmp (yrange, "0")) {
 	if (printmean || printrange) {
 	    nx = xdim;
 	    ny = ydim;
@@ -668,22 +742,24 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 	    nx = xdim;
 	    ny = ydim;
 	    for (y = 0; y < ny; y++) {
+		y1 = y + 1;
 		for (x = 0; x < nx; x++) {
+		    x1 = x + 1;
         	    dpix = getpix (image,bitpix,xdim,ydim,bzero,bscale,x,y);
 		    if (gtcheck && ltcheck) {
 			if (dpix > gtval && dpix < ltval) {
 			    if (nopunct)
-				printf ("%d %d %f\n", x+1, y+1, dpix);
+				printf ("%d %d %f\n", x1, y1, dpix);
 			    else
-				printf ("[%d,%d] = %f\n", x+1, y+1, dpix);
+				printf ("[%d,%d] = %f\n", x1, y1, dpix);
 			    }
 			}
 		    else if ((gtcheck && dpix > gtval) ||
 			(ltcheck && dpix < ltval)) {
 			if (nopunct)
-			    printf ("%d %d %f\n", x+1, y+1, dpix);
+			    printf ("%d %d %f\n", x1, y1, dpix);
 			else
-			    printf ("[%d,%d] = %f\n", x+1, y+1, dpix);
+			    printf ("[%d,%d] = %f\n", x1, y1, dpix);
 			}
 		    }
 		}
@@ -694,29 +770,37 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 	}
 
 /* Print entire columns */
-    else if (!strcmp (rrange, "0")) {
-	xrange = RangeInit (crange, xdim);
-	nx = rgetn (xrange);
+    else if (!strcmp (yrange, "0")) {
+
+	/* Make list of x coordinates */
+	crange = RangeInit (xrange, xdim);
+	nx = rgetn (crange);
+	xi = (int *) calloc (nx, sizeof (int));
+	for (i = 0; i < nx; i++) {
+	    xi[i] = rgeti4 (crange);
+	    }
+
 	ny = ydim;
-	for (ix = 0; ix < nx; ix++) {
-	    rstart (xrange);
-	    x = rgeti4 (xrange) - 1;
-	    for (y = 0; y < ny; y++) {
+	for (y = 0; y < ny; y++) {
+	    y1 = y + 1;
+	    for (ix = 0; ix < nx; ix++) {
+		x = xi[ix];
+		x1 = x + 1;
         	dpix = getpix (image,bitpix,xdim,ydim,bzero,bscale,x,y);
 		if (gtcheck || ltcheck) {
 		    if ((gtcheck && dpix > gtval) ||
 			(ltcheck && dpix < ltval)) {
 			procpix (&dsum, &dnpix, &dmin, &dmax, dpix);
 			if (nopunct)
-			    printf ("%d %d %f\n", x+1, y+1, dpix);
+			    printf ("%d %d %f\n", x1, y1, dpix);
 			else
-			    printf ("[%d,%d] = %f\n", x+1, y+1, dpix);
+			    printf ("[%d,%d] = %f\n", x1, y1, dpix);
 			}
 		    continue;
 		    }
 		else
 		    procpix (&dsum, &dnpix, &dmin, &dmax, dpix);
-	        if (bitpix > 0) {
+	        if (intout) {
 		    if (dpix > 0)
 	 		ipix = (int) (dpix + 0.5);
 		    else if (dpix < 0)
@@ -726,18 +810,18 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 		    }
 		if (pixperline) {
 		    printf ("%s[%d,%d] = ",name,x,y);
-		    if (bitpix > 0)
+		    if (intout)
 			printf (pform, ipix);
 		    else
 			printf (pform, dpix);
 		    printf ("\n");
 		    }
 		else {
-		    if (bitpix > 0)
+		    if (intout)
 			printf (pform, ipix);
 		    else
 			printf (pform, dpix);
-		    if ((y+1) % nline == 0)
+		    if ((y1) % nline == 0)
 			printf ("\n");
 		    else if (printtab)
 			printf ("\t");
@@ -750,17 +834,24 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 	    if (nx > 1 && !gtcheck && !ltcheck)
 		printf ("\n");
 	    }
-	free (xrange);
+	free (crange);
 	}
 
 /* Print entire rows */
-    else if (!strcmp (crange, "0")) {
-	yrange = RangeInit (rrange, xdim);
-	ny = rgetn (yrange);
+    else if (!strcmp (xrange, "0")) {
+
+	/* Make list of y coordinates */
+	rrange = RangeInit (yrange, ydim);
+	ny = rgetn (rrange);
+	yi = (int *) calloc (ny, sizeof (int));
+	for (i = 0; i < ny; i++) {
+	    yi[i] = rgeti4 (rrange);
+	    }
+
 	nx = xdim;
-	for (iy = 0; iy < ny; iy++) {
-	    y = rgeti4 (yrange) - 1;
-	    for (x = 0; x < nx; x++) {
+	for (x = 0; x < nx; x++) {
+	    for (iy = 0; iy < ny; iy++) {
+	        y = yi[iy];
         	dpix = getpix (image,bitpix,xdim,ydim,bzero,bscale,x,y);
 		if (gtcheck || ltcheck) {
 		    if ((gtcheck && dpix > gtval) ||
@@ -775,7 +866,7 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 		    }
 		else
 		    procpix (&dsum, &dnpix, &dmin, &dmax, dpix);
-	        if (bitpix > 0) {
+	        if (intout) {
 		    if (dpix > 0)
 	 		ipix = (int) (dpix + 0.5);
 		    else if (dpix < 0)
@@ -785,14 +876,14 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 		    }
 		if (pixperline) {
 		    printf ("%s[%d,%d] = ",name,x,y);
-		    if (bitpix > 0)
+		    if (intout)
 			printf (pform, ipix);
 		    else
 			printf (pform, dpix);
 		    printf ("\n");
 		    }
 		else {
-		    if (bitpix > 0)
+		    if (intout)
 			printf (pform, ipix);
 		    else
 			printf (pform, dpix);
@@ -809,86 +900,97 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 	    if (ny > 1 && !gtcheck && !ltcheck)
 		printf ("\n");
 	    }
-	free (yrange);
+	free (rrange);
 	}
 
-/* Print a region of a two-dimensional image */
-    else {
-	xrange = RangeInit (crange, xdim);
-	nx = rgetn (xrange);
+/* Print a region of a two-dimensional image sideways */
+    else if (bycol) {
 
-	/* Make list of y coordinates */
-	yrange = RangeInit (rrange, ydim);
-	ny = rgetn (yrange);
-	yi = (int *) calloc (ny, sizeof (int));
-	for (i = 0; i < ny; i++) {
-	    yi[i] = rgeti4 (yrange) - 1;
+	/* Make list of x coordinates */
+	rrange = RangeInit (xrange, xdim);
+	nx = rgetn (rrange);
+	xi = (int *) calloc (nx, sizeof (int));
+	for (i = 0; i < nx; i++) {
+	    xi[i] = rgeti4 (rrange);
 	    }
 
-	/* Label horizontal pixels */
+	/* Make list of x coordinates */
+	crange = RangeInit (yrange, xdim);
+	ny = rgetn (crange);
+	yi = (int *) calloc (ny, sizeof (int));
+	for (i = 0; i < ny; i++) {
+	    yi[i] = rgeti4 (crange);
+	    }
+
+	/* Set pixel label formats */
 	if (pixlabel) {
+
+	/* Format for row pixel labels */
+	    x = xi[nx-1];
+	    sprintf (testval, "%d", x);
+	    ndig = strlen (testval);
+	    if (printtab) {
+		sprintf (rform, "%%%dd:\t", ndig);
+		}
+	    else{
+		sprintf (rform, "%%%dd: ", ndig);
+		}
+
+	/* Format for column pixel labels */
+	    sprintf (testval, pform, 1.12345678);
+	    ndig = strlen (testval);
+	    y = yi[ny-1];
+	    sprintf (testval, "%d", y);
+	    ndig = ndig + strlen (testval);
+	    if (printtab) {
+		sprintf (cform, "%%%dd\t", ndig);
+		}
+	    else{
+		sprintf (cform, "%%%dd ", ndig);
+		}
+
+	/* Label column pixels */
 	    printf ("Coord");
-	    rstart (xrange);
-	    strcpy (nform, pform);
-	    if ((c = strchr (nform,'.')) != NULL) {
-		*c = 'd';
-		c[1] = (char) 0;
-		}
-	    else if ((c = strchr (nform,'f')) != NULL) {
-		*c = 'd';
-		}
-	    for (ix = 0; ix < nx; ix++) {
-		x = rgeti4 (xrange);
-		if (printtab)
-		    printf ("\t");
-		else
-		    printf (" ");
-		printf (nform, x);
+	    for (iy = 0; iy < ny; iy++) {
+		y = yi[iy];
+		printf (cform, y);
 		}
 	    printf ("\n");
 	    }
-	if (verbose)
-	    iy = -1;
-	else
-	    iy = ny;
 
-	/* Loop through rows starting with the last one */
-	for (i = 0; i < ny; i++) {
-	    if (verbose)
-		iy++;
-	    else
-		iy--;
-	    rstart (xrange);
+	/* Loop through rows */
+	for (ix = 0; ix < nx; ix++) {
+	    x1 = xi[ix];
+	    x = x1 - 1;
 	    if (pixlabel) {
-		printf ("%4d:",yi[iy]+1);
-		if (printtab)
-		    printf ("\t");
-		else
-		    printf (" ");
+		printf (rform, x1);
 		}
 
 	    /* Loop through columns */
-	    for (ix = 0; ix < nx; ix++) {
-		x = rgeti4 (xrange) - 1;
-        	dpix = getpix (image,bitpix,xdim,ydim,bzero,bscale,x,yi[iy]);
+	    for (iy = 0; iy < ny; iy++) {
+		y1 = yi[iy];
+		y = y1 - 1;
+        	dpix = getpix (image,bitpix,xdim,ydim,bzero,bscale,x,y);
 		if (gtcheck || ltcheck) {
 		    if ((gtcheck && dpix > gtval) ||
 			(ltcheck && dpix < ltval)) {
 			procpix (&dsum, &dnpix, &dmin, &dmax, dpix);
-			if (nopunct)
-			    printf ("%d %d %f\n", x+1, yi[iy]+1, dpix);
-			else
-			    printf ("[%d,%d] = %f\n", x+1, yi[iy]+1, dpix);
+			if (nopunct) {
+			    printf ("%d %d %f\n", x1, y1, dpix);
+			    }
+			else {
+			    printf ("[%d,%d] = %f\n", x1, y1, dpix);
+			    }
 			}
 		    continue;
 		    }
-		else
+		else {
 		    procpix (&dsum, &dnpix, &dmin, &dmax, dpix);
-		if (printrange || printmean)
+		    }
+		if (printrange || printmean) {
 		    continue;
-	        if (bitpix > 0) {
-		    if ((c = strchr (pform,'f')) != NULL)
-			*c = 'd';
+		    }
+		if (intout) {
 		    if (dpix > 0)
 	 		ipix = (int) (dpix + 0.5);
 		    else if (dpix < 0)
@@ -896,20 +998,148 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 		    else
 			ipix = 0;
 		    }
-		else {
-		    if ((c = strchr (pform,'d')) != NULL)
-			*c = 'f';
-		    }
 		if (pixperline) {
-		    printf ("%s[%d,%d] = ",name,x+1,yi[i]+1);
-		    if (bitpix > 0)
+		    printf ("%s[%d,%d] = ", name, x1, y1);
+		    if (intout)
 			printf (pform, ipix);
 		    else
 			printf (pform, dpix);
 		    printf ("\n");
 		    }
 		else {
-		    if (bitpix > 0)
+		    if (intout)
+			printf (pform, ipix);
+		    else
+			printf (pform, dpix);
+		    if ((iy+1) % nline == 0)
+			printf ("\n");
+		    else if (printtab)
+			printf ("\t");
+		    else
+			printf (" ");
+		    }
+		}
+	    if (!pixperline && !ltcheck && !gtcheck) {
+		if (!printrange && !printmean && iy % nline != 0)
+		    printf ("\n");
+		}
+	    }
+	free (rrange);
+	free (crange);
+	}
+
+/* Print a region of a two-dimensional image */
+    else {
+
+	/* Make list of x coordinates */
+	crange = RangeInit (xrange, xdim);
+	nx = rgetn (crange);
+	xi = (int *) calloc (nx, sizeof (int));
+	for (i = 0; i < nx; i++) {
+	    xi[i] = rgeti4 (crange);
+	    }
+
+	/* Make list of y coordinates */
+	rrange = RangeInit (yrange, ydim);
+	ny = rgetn (rrange);
+	yi = (int *) calloc (ny, sizeof (int));
+	for (i = 0; i < ny; i++) {
+	    yi[i] = rgeti4 (rrange);
+	    }
+
+	/* Set pixel label formats */
+	if (pixlabel) {
+
+	/* Format for row pixel labels */
+	    x = xi[nx-1];
+	    sprintf (testval, "%d", x);
+	    ndig = strlen (testval);
+	    sprintf (rform, "%%%dd:", ndig);
+	    if (printtab) {
+		sprintf (rform, "%%%dd:\t", ndig);
+		}
+	    else{
+		sprintf (rform, "%%%dd: ", ndig);
+		}
+
+	/* Format for column pixel labels */
+	    sprintf (testval, pform, 1.12345678);
+	    ndig = strlen (testval);
+	    y = yi[ny-1];
+	    sprintf (testval, "%d", y);
+	    ndig = ndig + strlen (testval);
+	    if (printtab) {
+		sprintf (cform, "%%%dd\t", ndig);
+		}
+	    else{
+		sprintf (cform, "%%%dd ", ndig);
+		}
+
+	/* Label column pixels */
+	    printf ("Coord");
+	    for (ix = 0; ix < nx; ix++) {
+		x = xi[ix];
+		printf (cform, x);
+		}
+	    printf ("\n");
+	    }
+
+	if (pixperline)
+	    iy = -1;
+	else
+	    iy = ny;
+
+	/* Loop through rows starting with the last one */
+	for (i = 0; i < ny; i++) {
+	    if (pixperline)
+		iy++;
+	    else
+		iy--;
+	    y1 = yi[iy];
+	    y = y1 - 1;
+	    if (pixlabel) {
+		printf (rform, y1);
+		}
+
+	    /* Loop through columns */
+	    for (ix = 0; ix < nx; ix++) {
+		x1 = xi[ix];
+		x = x1 - 1;
+        	dpix = getpix (image,bitpix,xdim,ydim,bzero,bscale,x,y);
+		if (gtcheck || ltcheck) {
+		    if ((gtcheck && dpix > gtval) ||
+			(ltcheck && dpix < ltval)) {
+			procpix (&dsum, &dnpix, &dmin, &dmax, dpix);
+			if (nopunct)
+			    printf ("%d %d %f\n", x1, y1, dpix);
+			else
+			    printf ("[%d,%d] = %f\n", x1, y1, dpix);
+			}
+		    continue;
+		    }
+		else {
+		    procpix (&dsum, &dnpix, &dmin, &dmax, dpix);
+		    }
+		if (printrange || printmean)
+		    continue;
+	        if (intout) {
+		    if (dpix > 0)
+	 		ipix = (int) (dpix + 0.5);
+		    else if (dpix < 0)
+		 	ipix = (int) (dpix - 0.5);
+		    else
+			ipix = 0;
+		    }
+		if (pixperline) {
+		    printf ("%s[%d,%d] = ", name, x1, y1);
+		    if (intout)
+			printf (pform, ipix);
+		    else
+			printf (pform, dpix);
+		    printf ("\n");
+		    }
+		else {
+		    if (intout)
 			printf (pform, ipix);
 		    else
 			printf (pform, dpix);
@@ -926,8 +1156,8 @@ int *xpix, *ypix;	/* Vectors of x,y coordinate pairs */
 		    printf ("\n");
 		}
 	    }
-	free (xrange);
-	free (yrange);
+	free (rrange);
+	free (crange);
 	}
 
     if (printmean) {
@@ -1038,4 +1268,10 @@ double	dpix;	/* Current pixel value */
  * Jan 10 2014	Add command line option @listfile as list of files
  *
  * Jun  9 2016	Fix isnum() tests for added coloned times and dashed dates
+ *
+ * May 12 2020	Reverse column and row assignment in range interpretation (Steve Willner)
+ * May 12 2020	Change range of values to -e and add -d for decimal places
+ * May 12 2020	Add -y to print columns as rows
+ * May 14 2020	Clean up distinctions between image x and y and output columns and rows
+ * May 14 2020	Add -o [format] to allow any legal C format for pixel display
  */
