@@ -50,7 +50,7 @@ static int logfile = 0;
 static int nproc = 0;
 static int first_file = 1;
 
-static char *RevMsg = "KEYHEAD WCSTools 3.9.5, 30 March 2017, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "KEYHEAD WCSTools 3.9.6, 14 May 2020, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
