@@ -14,7 +14,7 @@ extern int   ned_errno;
 static char searchorder[4];
 static int printall = 0;
 static void PrintUsage();
-static char *RevMsg = "SIMPOS 3.9.5, 30 March 2017, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "SIMPOS 3.9.6, 14 May 2020, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
